@@ -285,7 +285,7 @@ class Daemon(object):
             f.close()
 
         except IOError as ex:
-            logger.debug("pid file initialization failed, going exit(3), ex=%s", SolBase.extostr(ex))
+            logger.error("pid file initialization failed, going exit(3), ex=%s", SolBase.extostr(ex))
             sys.exit(3)
 
             # Ok
